"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/index.ts
var src_exports = {};
__export(src_exports, {
  CodeRenderer: () => CodeRenderer_default
});
module.exports = __toCommonJS(src_exports);

// src/components/CodeRenderer.tsx
var import_react = require("react");
var import_react_syntax_highlighter = require("react-syntax-highlighter");
var import_prism = require("react-syntax-highlighter/dist/esm/styles/prism");
var import_jsx_runtime = require("react/jsx-runtime");
var CopyIcon = ({ copied }) => /* @__PURE__ */ (0, import_jsx_runtime.jsx)(
  "svg",
  {
    xmlns: "http://www.w3.org/2000/svg",
    className: "h-5 w-5",
    fill: "none",
    viewBox: "0 0 24 24",
    stroke: copied ? "green" : "currentColor",
    strokeWidth: 2,
    children: /* @__PURE__ */ (0, import_jsx_runtime.jsx)(
      "path",
      {
        strokeLinecap: "round",
        strokeLinejoin: "round",
        d: "M8 7H7a2 2 0 00-2 2v10a2 2 0 002 2h10a2 2 0 002-2v-1M16 3H9a2 2 0 00-2 2v10a2 2 0 002 2h7a2 2 0 002-2V5a2 2 0 00-2-2z"
      }
    )
  }
);
var CodeRenderer = ({
  code,
  children,
  disableDefaultStyles = false,
  customClassNames = {},
  enableDarkMode = true
}) => {
  const [showCode, setShowCode] = (0, import_react.useState)(false);
  const [copied, setCopied] = (0, import_react.useState)(false);
  const [isDarkMode, setIsDarkMode] = (0, import_react.useState)(false);
  (0, import_react.useEffect)(() => {
    if (enableDarkMode) {
      const matchMedia = window.matchMedia("(prefers-color-scheme: dark)");
      setIsDarkMode(matchMedia.matches);
      const handleChange = () => setIsDarkMode(matchMedia.matches);
      matchMedia.addEventListener("change", handleChange);
      return () => {
        matchMedia.removeEventListener("change", handleChange);
      };
    }
  }, [enableDarkMode]);
  const copyToClipboard = () => {
    navigator.clipboard.writeText(code).then(() => {
      setCopied(true);
      setTimeout(() => setCopied(false), 2e3);
    });
  };
  const containerClassName = disableDefaultStyles ? customClassNames.container || "" : `${isDarkMode ? "bg-gray-900 text-gray-200" : "bg-gray-50 text-gray-900"} 
       p-4 border rounded-md shadow-lg transition-all duration-300 ease-in-out 
       ${customClassNames.container || ""}`;
  const buttonGroupClassName = disableDefaultStyles ? customClassNames.buttonGroup || "" : `flex ${isDarkMode ? "bg-gray-800" : "bg-gray-200"} 
       rounded-full p-1 transition-all duration-200 ease-in-out 
       ${customClassNames.buttonGroup || ""}`;
  const buttonClassName = disableDefaultStyles ? customClassNames.button || "" : `px-4 py-1.5 rounded-full transition-colors duration-200 ease-in-out 
       ${customClassNames.button || ""}`;
  const copyButtonClassName = disableDefaultStyles ? customClassNames.copyButton || "" : `flex items-center gap-2 text-sm font-medium 
       ${isDarkMode ? "text-gray-200" : "text-gray-900"} 
       hover:${isDarkMode ? "text-gray-400" : "text-gray-500"} 
       transition-all duration-200 ease-in-out 
       ${customClassNames.copyButton || ""}`;
  const codeBlockClassName = disableDefaultStyles ? customClassNames.codeBlock || "" : `mt-4 p-4 rounded-lg border ${isDarkMode ? "bg-gray-900 text-gray-200" : "bg-gray-50 text-gray-800"} 
       overflow-auto shadow-md transition-opacity duration-200 ease-in-out opacity-100 
       ${customClassNames.codeBlock || ""}`;
  return /* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", { className: containerClassName, children: [
    /* @__PURE__ */ (0, import_jsx_runtime.jsx)("div", { className: "flex justify-between items-center mb-4", children: /* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", { className: "flex items-center gap-4 ml-auto", children: [
      /* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", { className: buttonGroupClassName, children: [
        /* @__PURE__ */ (0, import_jsx_runtime.jsx)(
          "button",
          {
            onClick: () => setShowCode(false),
            className: `${buttonClassName} ${!showCode ? `${isDarkMode ? "bg-gray-700 text-gray-200" : "bg-white text-gray-900"}` : ""}`,
            children: "Preview"
          }
        ),
        /* @__PURE__ */ (0, import_jsx_runtime.jsx)(
          "button",
          {
            onClick: () => setShowCode(true),
            className: `${buttonClassName} ${showCode ? `${isDarkMode ? "bg-gray-700 text-gray-200" : "bg-white text-gray-900"}` : ""}`,
            children: "Code"
          }
        )
      ] }),
      /* @__PURE__ */ (0, import_jsx_runtime.jsxs)(
        "button",
        {
          onClick: copyToClipboard,
          className: copyButtonClassName,
          style: { minWidth: "110px" },
          children: [
            /* @__PURE__ */ (0, import_jsx_runtime.jsx)(CopyIcon, { copied }),
            /* @__PURE__ */ (0, import_jsx_runtime.jsx)("span", { children: copied ? "Copied!" : "Copy Code" })
          ]
        }
      )
    ] }) }),
    !showCode ? /* @__PURE__ */ (0, import_jsx_runtime.jsx)("div", { className: "transition-opacity duration-200 ease-in-out opacity-100", children }) : /* @__PURE__ */ (0, import_jsx_runtime.jsx)("div", { className: codeBlockClassName, children: /* @__PURE__ */ (0, import_jsx_runtime.jsx)(import_react_syntax_highlighter.Prism, { language: "tsx", style: import_prism.vscDarkPlus, children: code }) })
  ] });
};
var CodeRenderer_default = CodeRenderer;
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  CodeRenderer
});
